#
# spec file for package pluto
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pluto
Version:        5.22.1
Release:        1.1
Summary:        A cli tool to help discover deprecated apiVersions in Kubernetes
License:        Apache-2.0
URL:            https://github.com/FairwindsOps/pluto
Source:         pluto-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.1
BuildRequires:  zsh

%description
Pluto is a utility to help users find deprecated Kubernetes apiVersions in
their code repositories and their helm releases.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=%{version} \
   -X main.commit=${COMMIT_HASH}" \
   -o bin/pluto ./cmd/pluto/

%install
# Install the binary.
install -D -m 0755 ./bin/%{name} %{buildroot}/%{_bindir}/%{name}
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Thu Jul 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.22.1:
  * fix: remove Insights toast (#573)
* Wed Jul 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.22.0:
  * chore(deps): update tablewriter dependency (#572)
* Thu Jul 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.9:
  * INS-1201: Fix pluto vulnerability (#570)
  - golang.org/x/mod v0.25.0
  - helm.sh/helm/v3 v3.18.4
  - k8s.io/api v0.33.2
  - k8s.io/apimachinery v0.33.2
  - k8s.io/client-go v0.33.2
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.8:
  * Fixing issues (#568)
* Thu May 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.7:
  * docs: update instructions for verifying signatures
* Wed May 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.6:
  * fix: update goreleaser signing key
  * ci: update signing block
  * feat: go 1.24, update all deps (#567)
* Tue May  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.5:
  * fix: update golang.org/x/oauth2 to v0.27.0 to address
    CVE-2025-22868 (#565)
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 5.21.4:
  * Bump Go version to 1.23.1 (#561)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 5.21.3 (5.21.2 is on the same commit as
  5.21.1):
  * Bumped alpine to 3.21 (#557)
* Thu Jan  2 2025 opensuse_buildservice@ojkastl.de
- Update to version 5.21.1:
  * INSIGHTS-592 Fix Pluto vulerabilities (#556)
  * feat: add flowcontrol v1beta2 removal in 1.32 (#555)
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.21.0:
  * feat: add flowcontrol v1beta2 removal in 1.32
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.20.3:
  * INSIGHTS-374 Pluto: bump go to 1.22.7 (#553)
  * Managed by Terraform
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.20.2:
  * fix(release): update goreleaser to 2.2.0 (#550)
* Wed Aug 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.20.1:
  * fix: update golang to 1.22 and update other dependencies (#548)
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.20.0:
  * fix: remove tag annotation requirement (#547)
  * feat: add audit apiversion check (#546)
  * Bensky/kubeconfig flag (#545)
  * docs: update documentation from template (#544)
  * fix #432 don't compare when object kind doesn't match kind in
    last-applied-configuration (#542)
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- pluto withdrew the release 5.19.2 and 5.19.4 and re-released
  them
  https://github.com/FairwindsOps/pluto/issues/533
  Hence the package was rebuilt using the new 5.19.4 release
  https://github.com/FairwindsOps/pluto/releases/tag/v5.19.4
  https://github.com/FairwindsOps/pluto/commit/94d3acae30cd0c306a80fa42bb77a70b8f49e39c
- Update to version 5.19.4:
  * Bumped helm version (#537)
  * Add pluto module v5 back (#535)
  * Removed pluto v5 references (#534)
  * fix(release): fix goreleaesr
  * fix: goreleaser sign blob fix
  * fix(release): fix release; fix HIGH vulns (#532)
  * fix(release): another attempt to fix the release step (#531)
  * re-added equals sign (#530)
  * Sc/try cosign change (#529)
* Sun May  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.19.4 (skipping non-existent version 5.19.3):
  * Accept signature for cosign (#525)
* Sun May  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.19.2:
  * Bumped golang.org/x/net to v0.17.0 to fix HIGH vulnerabilities
    (#527)
* Wed Jan 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.19.1:
  * Bump goreleaser version to 1.22.1 (#518)
  * Fix FlowSchema typo in versions.yaml (#517)
  * Update documentation from template (#513)
  * Fix using REPL AVAIL/REPL AVAIL IN as custom columns (#515)
* Mon Dec 18 2023 kastl@b1-systems.de
- Update to version 5.19.0:
  * Update Dockerfile (#519)
* Thu Nov  9 2023 kastl@b1-systems.de
- Update to version 5.18.6:
  * Fixing isReplacementAvailableIn logic when field available in
    is empty (#516)
* Thu Oct 12 2023 kastl@b1-systems.de
- Update to version 5.18.5:
  * change logging for api discovery (#509)
  * Update dependencies 2023-10 (#511)
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 5.18.4:
  * Fix errant files
  * Fix exit code handling (#508)
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 5.18.3:
  * udpate dependencies (#505)
  * update the github action registry (#504)
* Tue Jul 25 2023 kastl@b1-systems.de
- Update to version 5.18.2:
  * Fix 501 (#502)
* Fri Jul 14 2023 kastl@b1-systems.de
- Update to version 5.18.1:
  * Fix the exit code documentation (#499)
* Wed Jul 12 2023 kastl@b1-systems.de
- Update to version 5.18.0:
  * Update FAQ with more details about last-applied-configuration
    issues (#498)
  * Fix the makefile for local dev (#496)
  * Add flowcontrol deprecations (#493)
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 5.17.0:
  * update the default target version of k8s to v1.25 (#492)
* Wed May 31 2023 kastl@b1-systems.de
- Update to version 5.16.4:
  * udpate deps (#490)
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 5.16.3:
  * Add a cosign 2.x command that works to validate the checksums
    (#484)
* Mon May 15 2023 kastl@b1-systems.de
- Update to version 5.16.2:
  * update dependencies (#483)
* Fri Apr 14 2023 kastl@b1-systems.de
- Update to version 5.16.1:
  * Update depencies and docker base image (#474)
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 5.16.0:
  * Update documentation from template (#459)
  * Suppress footer flag using --no-footer (#467)
* Thu Feb 23 2023 kastl@b1-systems.de
- Update to version 5.15.1:
  * add: set replacement-available-in to existing version. (#457)
* Thu Feb 23 2023 kastl@b1-systems.de
- Update to version 5.15.0:
  * Add a `detect-all-in-cluster` command to run both `detect-helm` and `detect-api-resources` (#455)
* Wed Feb 22 2023 kastl@b1-systems.de
- Update to version 5.14.0:
  * add replacement-available-in (#452)
* Tue Feb 21 2023 kastl@b1-systems.de
- Update to version 5.13.4:
  * Bump golang.org/x/net from 0.6.0 to 0.7.0 (#453)
* Sun Feb 12 2023 kastl@b1-systems.de
- Update to version 5.13.3:
  * fix : rules to load client configuration to connect to a kubernetes cluster (#419)
* Fri Feb 10 2023 kastl@b1-systems.de
- Update to version 5.13.2:
  * Update alpine to latest edge (#451)
* Fri Feb 10 2023 kastl@b1-systems.de
- Update to version 5.13.1:
  * update go modules (#450) (bsc#1208093, CVE-2023-25165)
* Mon Feb  6 2023 kastl@b1-systems.de
- Update to version 5.13.0:
  * fix: add removed-in to storage.k8s.io/v1beta1.CSIStorageCapacity (#448)
  * feat: add namespace and context to API Resources method (#410)
  * Fixed a linter error causing lack of compilation in Go 1.19 by removing deprecated io/ioutil functions and replacing them with their Go 1.16 counterparts. (#439)
  * Update alpine and other build dependencies (#433)
  * Remove experimental features in build (#429)
  * feat: allow hiding headers in output (#417)
  * Bump helm.sh/helm/v3 from 3.10.1 to 3.10.3 (#426)
* Thu Jan  5 2023 kastl@b1-systems.de
- Update to version 5.12.0:
  * Update documentation from template (#428)
  * sc/rd 71 add plg link (#427)
  * fix: preserve ordering of custom columns (#412)
  * Bump k8s.io/api from 0.25.3 to 0.25.4 (#406)
  * Bump k8s.io/apimachinery from 0.25.3 to 0.25.4 (#405)
  * Bump sigs.k8s.io/controller-runtime from 0.13.0 to 0.13.1 (#403)
  * Bump github.com/spf13/viper from 1.13.0 to 1.14.0 (#404)
  * Bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#402)
  * Bump alpine from 3.16.2 to 3.16.3 (#407)
* Mon Dec 12 2022 Robert Munteanu <rombert@apache.org>
- Install completions
* Tue Nov 15 2022 kastl@b1-systems.de
- Update to version 5.11.2:
  * update dependencies (#400)
* Fri Oct  7 2022 kastl@b1-systems.de
- Update to version 5.11.1:
  * Update go dependencies (#389)
  * Update documentation from template (#388)
* Sun Sep 25 2022 kastl@b1-systems.de
- Update to version 5.11.0:
  * Feature : Detect depcreated API's on a live cluster resources (#367)
  * Bump github.com/spf13/viper from 1.12.0 to 1.13.0 (#379)
  * Bump k8s.io/client-go from 0.25.0 to 0.25.1 (#381)
  * Bump k8s.io/klog/v2 from 2.70.1 to 2.80.1 (#378)
* Tue Sep 13 2022 kastl@b1-systems.de
- Update to version 5.10.7:
  * Bump sigs.k8s.io/controller-runtime from 0.12.3 to 0.13.0 (#376)
  * Bump github.com/rogpeppe/go-internal from 1.8.1 to 1.9.0 (#372)
  * Bump k8s.io/client-go from 0.24.4 to 0.25.0 (#375)
  * Updated docs for Target Versions (#356)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 5.10.6:
  * update helm (#371)
  * Bump k8s.io/client-go from 0.24.3 to 0.24.4 (#368)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 5.10.5:
  * Add CSIStorageCapacity deprecation (#365)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 5.10.4:
  * Update dependencies. Move to insights autoscan (#364)
  * Bump alpine from 3.16.0 to 3.16.2 (#362)
  * Bump helm.sh/helm/v3 from 3.9.2 to 3.9.3 (#361)
* Wed Jul 27 2022 kastl@b1-systems.de
- Update to version 5.10.3:
  * Detect duplicate deployed helm releases (#360)
  * Bump helm.sh/helm/v3 from 3.9.0 to 3.9.2 (#358)
  * Bump sigs.k8s.io/controller-runtime from 0.12.2 to 0.12.3 (#350)
  * Bump github.com/stretchr/testify from 1.7.4 to 1.8.0 (#344)
  * Bump k8s.io/klog/v2 from 2.70.0 to 2.70.1 (#349)
  * Fix repository name in Pluto (#348)
  * update Insights CI (#346)
* Wed Jul  6 2022 kastl@b1-systems.de
- Update to version 5.10.2:
  * Update docs publish step to use new standards (#345)
* Mon Jul  4 2022 kastl@b1-systems.de
- Update to version 5.10.1:
  * update docs (#343)
* Fri Jul  1 2022 kastl@b1-systems.de
- Update to version 5.10.0:
  * Allow package users to populate `Output.Deprecated|Removed` fields by exporting the `Instance.filterOutput` receiver. (#341)
  * update dependencies (#342)
* Mon Jun 27 2022 kastl@b1-systems.de
- Update to version 5.9.0:
  * Bump github.com/stretchr/testify from 1.7.2 to 1.7.4 (#338)
  * FWI-2191: Make versions.yaml available to users of Pluto packages, update Go module path with `/v5` (#331)
  * Bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#328)
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 5.8.0:
  * adding deployed state edge case to faq (#329)
  * Bump helm.sh/helm/v3 from 3.8.2 to 3.9.0 (#326)
  * Bump sigs.k8s.io/controller-runtime from 0.11.2 to 0.12.1 (#319)
  * Bump github.com/spf13/viper from 1.10.1 to 1.12.0 (#322)
  * Bump k8s.io/client-go from 0.23.5 to 0.24.1 (#323)
  * Bump alpine from 3.15 to 3.16.0 (#325)
  * Managed by Terraform
  * Managed by Terraform
  * Bump helm.sh/helm/v3 from 3.8.1 to 3.8.2 (#308)
  * Bump sigs.k8s.io/controller-runtime from 0.11.1 to 0.11.2 (#306)
  * Update license headers (#305)
  * Remove sonar config (#304)
* Fri Mar 25 2022 kastl@b1-systems.de
- Update to version 5.7.0:
  * Add flag for --kube-context (#302)
  * updated dependencies (#300)
* Fri Mar 18 2022 kastl@b1-systems.de
- Update to version 5.6.0:
  * Enable orb to use environment variables from context (#293)
  * Update cobra, viper, and helm dependencies (#292)
* Thu Mar 10 2022 kastl@b1-systems.de
- Update to version 5.5.3:
  * Feature/support env vars (#288)
* Tue Mar  8 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.17
* Tue Mar  8 2022 kastl@b1-systems.de
- Update to version 5.5.2:
  * Add PodSecurityPolicy removal in kube v1.25 (#287)
  * Managed by Terraform
  * Update goreleaser to 1.5.0 (#284)
* Wed Mar  2 2022 kastl@b1-systems.de
- Update to version 5.5.1:
  * fix/update versions according to k8s Deprecated API Migration Guide (#283)
* Fri Feb 25 2022 kastl@b1-systems.de
- Update to version 5.5.0:
  * autoscaling/v2beta2 replacement should be autoscaling/v2 (#281)
  * Add CSV output option (#279)
* Mon Feb 21 2022 kastl@b1-systems.de
- Update to version 5.4.1:
  * Update all dependencies (#276)
  * Update dependencies (#272)
  * Document cosign, and add to release notes (#264)
  * Update documentation from template (#262)
* Wed Feb 16 2022 kastl@b1-systems.de
- Update to version 5.4.0:
  * Add support for parsing manifests contained into List objects (#263)
* Tue Feb 15 2022 kastl@b1-systems.de
- Update to version 5.3.5:
  * Remove invalid istio version entry (#259)
* Wed Jan 26 2022 kastl@b1-systems.de
- Update to version 5.3.4:
  * checking if the deprecation and removal variables are true (#253)
* Wed Jan 26 2022 kastl@b1-systems.de
- Update to version 5.3.3:
  * Fix replacement versions for some APIs (#252)
* Sat Jan 15 2022 kastl@b1-systems.de
- Update to version 5.3.2:
  * install tools for docs publishing (#250)
  * Managed by Terraform
* Sat Jan 15 2022 kastl@b1-systems.de
- Update to version 5.3.1:
  * Delete .github/ISSUE_TEMPLATE/bug_report.md
  * Managed by Terraform
  * Delete .github/ISSUE_TEMPLATE/bug.yaml
  * Fix flags on cosign. Install vault for publishing docs (#249)
* Sat Jan 15 2022 kastl@b1-systems.de
- Update to version 5.3.0:
  * Change variable name
  * Managed by Terraform
  * Delete .github/ISSUE_TEMPLATE/bug_report.md
  * Fix docker login command again
  * Missing $ in docker login (#248)
  * Fix docker login for releaes (#247)
  * Use cosign to sign images and push to GCP artifact registry (#246)
  * Delete .github/stale.yml
* Tue Jan 11 2022 kastl@b1-systems.de
- Update to version 5.2.6:
  * Add deprecated cert-manager versions (#245)
* Sun Jan  9 2022 kastl@b1-systems.de
- Update to version 5.2.5:
  * set -e so script exits with proper exit code (#243)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.2.4:
  * updating scripts to run pluto commands (#241)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.2.3:
  * installing pluto command into cimg executor (#240)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.2.2:
  * Fix release request script (#236)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.2.1:
  * Fix orb publish request secret and insights secret (#235)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.2.0:
  * Add missing storage and apiregistration deprecations (#234)
  * Work on orb publishing (#232)
  * creating circleci orb for pluto (#228)
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.16
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.1.1:
  * Update goreleaser to v1.1.0 (#230)
  * Managed by Terraform
  * added github action (#225)
  * Only pull in klog's v flag for logging (#223)
  * Add doc for scoop install on Windows (#222)
  * Managed by Terraform
  * make sure proper tag is used on release (#220)
  * Update goreleaser version (#218)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.1.0:
  * Revert yaml dependence due to panic. Remove pkger (#216)
  * HPA v2beta2 deprecation should be in k8s 1.23 (#213)
  * Add optional support for custom columns in markdown output (#206)
  * temporarily disable sonarqube (#209)
  * Use go 1.17 and update kube/helm modules (#204)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.0.1:
  * Windows build support (#203)
  * Update documentation from template (#201)
  * Update README.md (#198)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 5.0.0:
  * Update versions.yaml (#195)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 4.3.0:
  * Fix dirty git state on release (#194)
  * Setup pluto for prerelease. Use bash in relesae (#193)
  * Fix name in goreleaser (#192)
  * Multi-arch build. Update goreleaser. Use Docker for goreleaser (#191)
  * update deps (#170)
  * Update documentation from template (#187)
  * Removed unnecessary GO111MODULE=on (#184)
  * add banner (#179)
  * Adjust removed-in version for PriorityClass (#183)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 4.2.0:
  * add back FAQ link (#171)
  * Update dependencies. Add Sonarqube (#169)
  * Update README.md (#168)
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package pluto
